// Function to ensure the 'Following' tab is selected
function ensureFollowingTabSelected() {
    // Only consider visible tabs
    const followingTab = Array.from(document.querySelectorAll('a[role="tab"]'))
        .filter(tab => tab.offsetParent !== null) // Ensure it's visible
        .find(tab => tab.textContent.trim() === 'Following');

    if (followingTab && followingTab.getAttribute('aria-selected') !== 'true') {
        // Randomized delay to mimic human behavior
        setTimeout(() => {
            followingTab.click();
        }, Math.random() * 2000 + 1000); // Random delay between 1-3 seconds
    }
}

// Debounced click listener
function debounce(func, delay) {
    let timeout;
    return function (...args) {
        clearTimeout(timeout);
        timeout = setTimeout(() => func.apply(this, args), delay);
    };
}

// Add a debounced listener for clicks
document.addEventListener('click', debounce(() => {
    ensureFollowingTabSelected();
}, 1000)); // 1-second debounce

// Initial load check with a delay
setTimeout(() => {
    ensureFollowingTabSelected();
}, Math.random() * 2000 + 1000); // Random delay between 1-3 seconds
